/*
 * Copyright 2016-2019 the original author or authors.
 *
 * This file is part of the JHipster project, see https://www.jhipster.tech/
 * for more information.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.blackdread.lib.restfilter.filter;

import java.math.BigDecimal;
import java.util.List;

/**
 * Filter class for {@link BigDecimal} type attributes.
 *
 * @see RangeFilter
 */
public class BigDecimalFilter extends RangeFilter<BigDecimal> {

    private static final long serialVersionUID = 1L;

    public BigDecimalFilter() {
    }

    public BigDecimalFilter(final BigDecimalFilter filter) {
        super(filter);
    }

    public BigDecimalFilter copy() {
        return new BigDecimalFilter(this);
    }

    @Override
    public BigDecimalFilter setEquals(BigDecimal equals) {
        super.setEquals(equals);
        return this;
    }

    @Override
    public BigDecimalFilter setSpecified(Boolean specified) {
        super.setSpecified(specified);
        return this;
    }

    @Override
    public BigDecimalFilter setIn(List<BigDecimal> in) {
        super.setIn(in);
        return this;
    }

    @Override
    public BigDecimalFilter setGreaterThan(BigDecimal greaterThan) {
        super.setGreaterThan(greaterThan);
        return this;
    }

    @Override
    public BigDecimalFilter setGreaterThanOrEqual(BigDecimal greaterThanOrEqual) {
        super.setGreaterThanOrEqual(greaterThanOrEqual);
        return this;
    }

    @Override
    public BigDecimalFilter setLessThan(BigDecimal lessThan) {
        super.setLessThan(lessThan);
        return this;
    }

    @Override
    public BigDecimalFilter setLessThanOrEqual(BigDecimal lessThanOrEqual) {
        super.setLessThanOrEqual(lessThanOrEqual);
        return this;
    }
}
